import { Observable, Subscription } from 'rxjs';
import { Vasat, VasatSearchQuery, User, VasatSession, VasatModelClass, Role } from "vasat";
import { Account, Dataset, Folder, DatasetType, TransformType, PlottableModel, Project, ProcessorAPI, AccountPlan, JobType, Tag, Widget } from './4d-objects';
import { ServerProcess } from './4d-processor.service';
/**
 * <p>Interface that outlines common properties of a processing task event.</p>
 */
export interface TaskEvent {
    event: string;
    task: ServerProcess;
    finished: boolean;
    error: boolean;
}
/**
 * <p>Service containing useful methods to communicate with server.</p>
 */
export declare class FourDService {
    V: Vasat;
    playground: Dataset[];
    FILTER_PLOTABLE: string;
    FILE_UPLOADED: string;
    FILE_FAILED: string;
    FILE_CNX: string;
    FILE_ADDED: string;
    FILE_BEFORE_UL: string;
    FILE_PROGRESS: string;
    teams: Account[];
    domainConfig: any;
    domain: Account;
    sampleAccount: Account;
    rootAccounts: Account[];
    activeTeam: Account;
    activeUser: User;
    activeWidgets: Widget[];
    datasetTypes: DatasetType[];
    transformTypes: TransformType[];
    plans: AccountPlan[];
    projects: Project[];
    apis: ProcessorAPI[];
    jobTypes: JobType[];
    tags: Tag[];
    filters: {};
    activeDataset: Dataset;
    uploadChunkSize: number;
    runningTasks: ServerProcess[];
    runningTasksMap: {
        [datasetId: string]: ServerProcess;
    };
    uploadsRunning: ServerProcess[];
    uploadsRunningMap: {
        [id: string]: ServerProcess;
    };
    uploadsQueued: ServerProcess[];
    uploadsQueuedMap: {
        [id: string]: ServerProcess;
    };
    roles: Role[];
    testing: string;
    private _runningTaskSubject;
    runningTasksObservable: Observable<TaskEvent>;
    private _uploadsRunningSubject;
    uploadsRunningObservable: Observable<TaskEvent>;
    private _accountChangeSubject;
    accountChangeObservable: Observable<Account>;
    private _activeAccountObservable;
    private _accountsObservale;
    private _socketSubject;
    private _socketObservable;
    private _socketCommands;
    private socket;
    constructor(V: Vasat);
    /**
     * <p>Logout of current user.</p>
     */
    logout(): Observable<void>;
    /**
     * <p>Removes active team.</p>
     */
    clearStates(): void;
    onV2Init(): Observable<[ProcessorAPI[], JobType[]]>;
    getQuotas(): Observable<any>;
    /**
     * <p>Returns an observable of an [[Account]] object. If it does not have a team or get sample [[Account]].</p>
     * <footer>Note: throws exception if not logged in.</footer>
     */
    onReady(): Observable<Account[]>;
    /**
     * <p>If [[ServerProcess]] is not already running, add it. Otherwise update it.</p>
     * @param t The [[ServerProcess]] to add.
     */
    addTask(t: ServerProcess): void;
    /**
     * Remove the [[ServerProcess]] task.
     * @param task The task to remove.
     * @param err if the task ended in error set to true.
     */
    removeTask(task: ServerProcess, err?: boolean): void;
    /**
     * <p>Uploads file using [[ChunkedFileUploader]].</p>
     * @param ds [[Dataset]] to upload associated file.
     * @param f File to be uploaded.
     * @param filename Name of file.
     * @param chunkSize Size of chunks when uploading.
     */
    uploadFile(ds: Dataset, f: File, filename?: string, chunkSize?: number): ServerProcess;
    _deQueue(): void;
    /**
     * <p>Queries for <a href="https://docs.vasat.io/">Vasat</a> Model class and returns a <a href=" linkToVasat ">VasatSeachQuery</a>.</p>
     * @param objectType The Vasat model you want to query for.
     */
    searchFor<T extends PlottableModel<T>>(objectType: VasatModelClass<T>): VasatSearchQuery<T>;
    /**
     * <p>Returns observable of [[Account]] if it exists. Else throws exception.</p>
     */
    onActiveAccountReady(): Observable<Account>;
    tryingAccount: string;
    /**
     * <p>Note that this is for advanced users with multiple teams. If you are a single user this does not apply.</p>
     * <p>Sets the active team to given accountId, so all subsequent api calls that are made will return things that only this accountId can see.</p>
     * @param accountId
     */
    setActiveTeam(accountId: string): Observable<Account>;
    socketUp: boolean;
    /**
     * <p>Initialise WebSocket.</p>
     * @param s
     */
    initSocket(s: VasatSession): void;
    /**
     * <p>Try to reinitialise WebSocket.</p>
     * @param s An active <a href=" linkToVasat ">Vasat Session</a>.
     * @param e Error or exception.
     */
    retrySocket(s: VasatSession, e: any): void;
    /**
     * <p>Close WebSocket.</p>
     */
    deinitSocket(): void;
    /**
     * <p>If command does not exist, create one and return.</p>
     * @param cmd Socket command.
     */
    onSocketCommand(cmd: string): Observable<any>;
    /**
     * <p>Transmist data to server.</p>
     * @param a Data to send.
     */
    sendSocket(a: any): void;
    /**
     * <p>Return [[ProcessorAPI]] of given type.</p>
     * @param apiType The type of transformation from this API.
     */
    getApi(apiType: string): ProcessorAPI;
    /**
     *
     * @param folderId retun the chain of folders going up to the root folder for the specified folder Id
     */
    getFolderChain(folderId: number, cache?: boolean): Observable<Folder[]>;
}
/**
 * <p>Base component class to extend that initialises common properties, and calls [[onReady]] when initialising is finished.</p>
 */
export declare class BaseComponent {
    protected _4D: FourDService;
    private _account;
    loading: boolean;
    sub: Subscription;
    activeUser: User;
    constructor(_4D: FourDService, _account?: string);
    /**
     * <p>Initialises some properties that will be commonly used among your components.</p>
     */
    ngOnInit(): void;
    /**
     * <p>This is called when initialisation has finished. Your components should do their initialisation here.</p>
     */
    onReady(): void;
    /**
     * <p>Unsubscribes from subscription when component destroyed.</p>
     */
    ngOnDestroy(): void;
}
