import { Observable } from 'rxjs';
import { VasatModel, VasatSearchQuery, SearchResults, User, VasatConnection, ToManyList, AccessGroup, GUIDModel } from "vasat";
import { FourDService } from './4d-mapper.service';
export interface Quote {
    amount: number;
    unit: string;
}
export interface AccountPlanImpl {
    maxStorage: number;
    maxTeams: number;
    maxProjects: number;
    maxUsers: number;
    price: number;
    allAdjustments: {
        [ket: string]: number;
    };
}
/**
 * <p>Reference to Coordinate Reference System (CRS). More details on EPSG can be found <a href="https://www.puzzlr.org/epsg-codes-explained/">here</a>.</p>
 */
export declare class EPSGCodes extends VasatModel<EPSGCodes> {
    constructor(V: VasatConnection, args?: any);
    uid: string;
    CSRType: string;
    areaCode: string;
}
export declare class Widget extends VasatModel<Widget> {
    uid: string;
    group: string;
    features: string[];
    noteworthy: boolean;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>Defines the cost and limitations of the [[Account]].</p>
 */
export declare class AccountPlan extends VasatModel<AccountPlan> {
    cost: number;
    maxUsers: number;
    maxTeams: number;
    maxStorage: number;
    seq: number;
    isTrial: boolean;
    monthlyCredit: number;
    availableWidgets: ToManyList<Widget>;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>Client object that is used to get the token</p>
 */
export declare class Client extends VasatModel<Client> {
    token: String;
    secret: string;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>Account class that is used for access control.</p>
 */
export declare class Account extends VasatModel<Account> {
    uid: string;
    demos: any[];
    tou: any;
    isDomain: boolean;
    widgets: string[];
    plan: AccountPlan;
    parent: Account;
    accountGroups: ToManyList<AccessGroup>;
    invitedUsers: ToManyList<User>;
    canWrite: boolean;
    autoCredit: number;
    adhocCredit: number;
    planToDate: number;
    constructor(V: VasatConnection, args?: any);
    GUID(): string;
    GUID_FIELD_NAME(): string;
    /**
     * <p>Updates values of this object with parameter object values.</p>
     * @param a The object that you want to copy values of.
     */
    set(a: any): this;
    /**
     * <p>Parse this object to JSON format.</p>
     */
    toJSON(): any;
    /**
     * <p>Checks if the account has the passed API type enabled.</p>
     * @param apiType
     */
    hasApiEnabled(apiType: string): boolean;
    /**
     * <p>Enable/Disable API type</p>
     * @param apiType The API type you want to manipulate
     * @param enable True = Enable, False = Disable
     */
    enableDisableApi(apiType: string, enable: boolean): Observable<Account>;
    accountPlanDetails(p?: AccountPlan): Observable<AccountPlanImpl>;
    previewPlan(sliders: AccountPlanImpl, p: AccountPlan): Observable<AccountPlanImpl>;
    updatePlan(sliders: AccountPlanImpl, p: AccountPlan): Observable<Account>;
    buyCredit(amount: Number): Observable<Account>;
}
/**
 * <p>AccountableModel is a model with an [[Account]], so that they are not accessible to the public.</p>
 */
export declare class AccountableModel<T extends AccountableModel<T>> extends VasatModel<T> {
    account: Account;
    canWrite: boolean;
    canDelete: boolean;
    /**
     * <p>Retrieves this object</p>
     */
    fetchObservable(): any;
    /**
     * <p>Updates values of this object with parameter object values.</p>
     * @param a The object that you want to copy values of.
     */
    set(a: any): this;
    /**
     * <p>Parse this object to JSON format.</p>
     */
    toJSON(): any;
}
export declare class Tag extends AccountableModel<Tag> {
    category: string;
    rank: number;
    colour: string;
    date: number;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>ProcessorAPIs are very similar to [[TransformType]]s in that they describe the process that a [[Dataset]] will undergo, however ProcessorAPIs are third party processes that need to be set up.
 * These ProcessorAPIs are linked to the account.</p>
 */
export declare class ProcessorAPI extends AccountableModel<ProcessorAPI> {
    needsInput: boolean;
    type: string;
    url: string;
    processorImpl: string;
    qMap: any;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>Defines the type of transformation that a [[Dataset]] object will undergo.</p>
 */
export declare class TransformType extends VasatModel<TransformType> {
    uid: string;
    category: string;
    pluginType?: string;
    icon: string;
    apis: ToManyList<ProcessorAPI>;
    createType: DatasetType;
    isSubTransform: TransformType;
    needsCRS: boolean;
    isFolder: boolean;
    needsInput: boolean;
    qMap: any[];
    constructor(V: VasatConnection, args?: any);
    GUID(): string;
    GUID_FIELD_NAME(): string;
}
/**
 * <p>PlottableModel's are models/images that can be added to and displayed on the map.</p>
 */
export declare class PlottableModel<T extends PlottableModel<T>> extends AccountableModel<T> {
    llat: number;
    llng: number;
    lheight: number;
    ulat: number;
    ulng: number;
    uheight: number;
    latitude: number;
    longitude: number;
    height: number;
    pitch: number;
    heading: number;
    roll: number;
    vertical_offset: number;
    matrix: number[];
    rawType: string;
    transformType: TransformType;
    /**
     * <p>Gets <a href="https://cesiumjs.org/Cesium/Build/Documentation/Rectangle.html">Cesium Rectangle</a> of this PlottableModel object.</p>
     */
    rectangle(): any;
    /**
     * <p>Gets <a href="https://cesiumjs.org/Cesium/Build/Documentation/Cartographic.html">Cesium Cartographic</a> from longitude and latitude specified in degrees</p>
     */
    cartographic(): any;
    /**
     * <p>Creates a new <a href="https://cesiumjs.org/Cesium/Build/Documentation/Cartesian3.html">Cesium Cartesian3</a> instance from a Cartographic input.</p>
     */
    catresian(): any;
}
/**
 * <p>DatasetType is used to associate the [[Dataset]] with the [[TransformType]]. When a file is uploaded, the type of file should be auto-detected to determine the necessary [[TransformType]]s to be added in the appropriate lists ([[adhocTransforms]]/[[autoApplyTransforms]]).</p>
 */
export declare class DatasetType extends AccountableModel<DatasetType> {
    uid: string;
    extension: string;
    canPlot: boolean;
    canDownload: boolean;
    /**
     * <p>Custom TransformTypes that may be applied to a [[Dataset]].</p>
     */
    adhocTransforms: ToManyList<TransformType>;
    /**
     * <p>The [[TransformType]] to auto-apply when the Dataset is detected.</p>
     */
    autoApplyTransforms: ToManyList<TransformType>;
    _adhocTransforms: TransformType[];
    constructor(V: VasatConnection, args?: any);
    set(a: any): this;
    /**
     * <p>Parse this object to JSON format.</p>
     */
    toJSON(): any;
    GUID(): string;
    GUID_FIELD_NAME(): string;
}
/**
 * <p>Folders contain the [[Dataset]]s or [[Transform]]s.</p>
 */
export declare class Folder extends AccountableModel<Folder> implements GUIDModel {
    parent: Folder;
    forJobBatch: JobBatch;
    forScene: TransformGroup;
    forProject: Project;
    /**
     * @depricated
     */
    transform: TransformType;
    linkedFiles: ToManyList<Dataset>;
    fid: string;
    root: any;
    uid: string;
    constructor(V: VasatConnection, args?: any);
    GUID(): string;
    GUID_FIELD_NAME(): string;
    /**
     * <p>Updates values of this object with parameter object values.</p>
     * @param a The object that you want to copy values of.
     */
    set(a: any): this;
    /**
     * <p>Parse this object to JSON format.</p>
     */
    toJSON(): any;
    getMeta(): {};
    /**
     * <p>Returns <a href="https://fontawesome.com/">Font Awesome</a> icon string identifier for folder.</p>
     * @param s
     */
    getIcon(s: FourDService): "fa-users" | "fa-briefcase" | "fa-folder-o";
}
/**
 * <p>A file to be transformed depending on the [[TransformType]].</p>
 */
export declare class Dataset extends AccountableModel<Dataset> {
    private ncur?;
    folder: Folder;
    dataType: DatasetType;
    crs: EPSGCodes;
    status: string;
    incomplete: boolean;
    incomplete_offset: number;
    incomplete_seq: number;
    incomplete_total: number;
    initParams: any;
    /**
     * <p>Array of the ID's of all completed [[Transform]]s that have been applied to this Dataset.</p>
     */
    transformIds: number[];
    /**
     * <p>Array of the uid's of all completed [[TransformType]]s that have been applied to this Dataset.</p>
     */
    transforms: string[];
    linkedInFolders: ToManyList<Dataset>;
    constructor(V: VasatConnection, args?: any, ncur?: boolean);
    /**
     * <p>Begins transform process depending on the [[TransformType]].</p>
     * @param tt [[TransformType]] you want to use
     * @param args
     */
    applyTransform(tt: TransformType, args?: any, customAPI?: ProcessorAPI): Observable<any>;
    toJSON(): any;
    quoteTransform(tt: TransformType): Observable<any>;
    uploadString(str: string, filename?: string): Observable<any>;
}
/**
 * <p>Stores information related to plan and pay cycle etc.</p>
 */
export declare class BillingSetup extends AccountableModel<BillingSetup> {
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>Invoice</p>
 */
export declare class Invoice extends AccountableModel<Invoice> {
    uid: string;
    invNumber: string;
    receiptUrl: string;
    ammount: number;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>Individual items to be charged on invoices.</p>
 */
export declare class InvoiceItem extends AccountableModel<InvoiceItem> {
    invoice: Invoice;
    plan: BillingSetup;
    units: number;
    fromDate: number;
    toDate: number;
    constructor(V: VasatConnection, args?: any);
}
/**
 * <p>A group of [[Dataset]]s.</p>
 */
export declare class DatasetGroup extends AccountableModel<DatasetGroup> {
    children: ToManyList<Dataset>;
    parent: DatasetGroup;
    fid: string;
    constructor(V: VasatConnection, args?: any);
    /**
     * <p>Appends the given [[Dataset]]s.</p>
     * @param ds An array of [[Dataset]]
     */
    addChildren(ds: Dataset[]): Observable<Dataset[]>;
    /**
     * <p>Removes the given [[Dataset]].</p>
     * @param ds An array of [[Dataset]]
     */
    delChildren(ds: Dataset[]): Observable<Dataset[]>;
    /**
     * <p>Returns <a href=" link to vasatsearchresults ">Vasat Search Results</a>.</p>
     */
    getChildren(): Observable<SearchResults<Dataset>>;
}
/**
 * <p>Transform objects are plottable objects. Transforms have several different [[TransformType]]s. The different types of transforms are: kml, laz, photo-dzi, terrain tiles*, three-d-tiles*, tms
 * <footer>Note: The types denoted by an asterix(*) are 3D models that are currently only supported by our Cesium helper class ([[FourdCesiumHelper]]).</footer></p>
 */
export declare class Transform extends PlottableModel<Transform> {
    private ncur?;
    input: Dataset;
    tags: ToManyList<Tag>;
    outputs: Dataset[];
    savedAnnots: any[];
    vertical_offset: number;
    metadata: any;
    isProxy: boolean;
    transform?: {
        translate: any;
        heading: any;
        pitch: any;
        roll: any;
    };
    /**
     * ID of transform that it can plot
     */
    canPlot: number;
    pointCloudShading: any;
    status: 'processing' | 'error' | 'failed' | 'finished';
    /**
     * Extra info if the transfrom is a proxy
     */
    proxyMeta: any;
    ds_type_uid: string;
    ds_name?: string;
    constructor(V: VasatConnection, args?: any, ncur?: boolean);
    /**
     * <p>Updates values of this object with parameter object values.</p>
     * @param a The object that you want to copy values of.
     */
    set(a: any): this;
    /**
     * <p>Gets the [[Annotation]]s for this Transform object.</p>
     */
    getAnnotations(): Observable<Annotation[]>;
    toJSON(): any;
}
/**
 * <p>Project is a collection of data, which can be shared with other [[User]]s or [[Client]]s.</p>
 */
export declare class Project extends PlottableModel<Project> {
    transforms: ToManyList<Transform>;
    photos: ToManyList<Transform>;
    datasets: ToManyList<Dataset>;
    /**
     * @depricated
     */
    folders: ToManyList<Folder>;
    shareUsers: ToManyList<User>;
    shareClients: ToManyList<Client>;
    tags: ToManyList<Tag>;
    get projectFolder(): Observable<Folder>;
    constructor(V: VasatConnection, args?: any);
    /**
     * <p>Create a new [[Folder]].</p>
     */
    addTransformsFromFolder(f: Folder, filterType?: TransformType[]): Observable<number>;
    /**
     * <p>Clear all Transforms.</p>
     */
    removeAllTransforms(filterType?: TransformType[]): Observable<number>;
    /**
     * <p>Retrieves the list of [[TransformGroup]]s associated with this Project object.</p>
     */
    groupList(): Observable<TransformGroup[]>;
}
/**
 * <p>A group of [[Transform]] objects.</p>
 */
export declare class TransformGroup extends AccountableModel<TransformGroup> {
    children: ToManyList<Transform>;
    photos: ToManyList<Transform>;
    parent: TransformGroup;
    project: Project;
    /**
     * stop using this
     * @depricated
     */
    folder: Folder;
    tags: ToManyList<Tag>;
    fid: string;
    _cachedTransforms: Transform[];
    _photo_count: number;
    layerProps: any;
    get sceneFolder(): Observable<Folder>;
    constructor(V: VasatConnection, args?: any);
    /**
     * <p>Adds all the images from the specified [[Folder]] to this TransformGroup. Action will also add the same photos to the [[Project]]s photos and any Photogrammetry [[Job]].</p>
     */
    addImagesFromFolder(f: Folder): Observable<any>;
    /**
     * <p>Remove any images associated with this TransformGroup object.</p>
     */
    removeAllImages(): Observable<number>;
    /**
     * <p>Add [[Transform]](s) to this TransformGroup object.</p>
     * @param ds Objects to add
     */
    addChildren(ds: Transform[]): Observable<Transform[]>;
    /**
     * <p>Remove [[Transform]](s) to this TransformGroup object.</p>
     * @param ds Objects to remove
     */
    delChildren(ds: Transform[]): Observable<Transform[]>;
    addFromFiles(ds: Dataset[]): Observable<{
        photos: number[];
        transforms: number[];
    }>;
    /**
     * <p>Retrieves the [[Transform]]s associated with this TransformGroup object.</p>
     */
    getChildren(): Observable<SearchResults<Transform>>;
    /**
     * <p>Gets the Shapes at a given point of this TransformGroup object.</p>
     * @param latDeg Latitude in degrees
     * @param lngDeg Longitude in degrees
     * @param height
     */
    queryShapesAtPoint(latDeg: Number, lngDeg: Number, height?: number): Observable<any>;
    /**
     * <p>Parse this object to JSON format.</p>
     */
    toJSON(): any;
    isShowing(t: Transform): any;
    setShowing(t: Transform, showing: boolean): void;
    getAlpha(t: Transform): any;
    setAlpha(t: Transform, opacity: number): void;
    getSceneFolder(): Observable<Folder>;
}
/**
 * <p>Describes the different [[TransformType]]s that the [[Job]] will undertake.</p>
 */
export declare class JobType extends VasatModel<JobType> {
    uid: string;
    category: string;
    pluginType: 'free' | 'paid';
    icon: string;
    baseTransform: TransformType;
    subTransforms: ToManyList<TransformType>;
    constructor(V: VasatConnection, args?: any);
    GUID(): string;
    GUID_FIELD_NAME(): string;
}
/**
 * <p>Job outlines the [[Dataset]](s) that will be transformed depending on the [[JobType]]/[[TransformType]].</p>
 */
export declare class Job extends AccountableModel<Job> {
    status: string;
    jobType: JobType;
    scene: TransformGroup;
    processorAPI: ProcessorAPI;
    inputDatasets: ToManyList<Dataset>;
    inputFolders: ToManyList<Folder>;
    constructor(V: VasatConnection, args?: any);
    /**
     * <p>Queries for the associated [[JobBatch]] and reurns a <a href=" linkToVasat ">VasatSearchQuery</a> containging the results.</p>
     */
    batches(): VasatSearchQuery<JobBatch>;
    /**
     * <p>Refresh the status of processing.</p>
     */
    refreshStatus(): Observable<any>;
    /**
     * <p>Starts the processing.</p>
     * @param t
     * @param args
     */
    startTransform(t: TransformType, args?: any, customAPI?: ProcessorAPI): Observable<any>;
    /**
     * <p>Retrieve estimated cost of Job.</p>
     */
    getEstimatedPrice(t: TransformType): Observable<{
        amount: number;
        unit: string;
    }>;
    /**
     * <p>Start checkout process.</p>
     * @param noonce
     */
    makePayment(noonce: string): Observable<{
        amount: number;
        unit: string;
    }>;
    quoteTransform(tt: TransformType): Observable<Quote>;
}
/**
 * <p>A JobBatch is a child of a [[Job]] that is undergoing a process or has already undergone transformation. A key difference to a [[Job]] is that it only has one [[TransformType]].</p>
 * <footer>Note that you will have to create a new [[Folder]] containing the outputs.</footer>
 */
export declare class JobBatch extends AccountableModel<JobBatch> {
    parent: Job;
    transformType: TransformType;
    params: any;
    status: 'finished' | 'failed' | 'processing';
    outputs: ToManyList<Dataset>;
    constructor(V: VasatConnection, args?: any);
    getBatchFolder(): Observable<Folder>;
}
/**
 * <p>Annotations are plottable objects. Usually pins/markers/measurements.</p>
 */
export declare class Annotation extends PlottableModel<Annotation> {
    transform: Transform;
    project: Project;
    uid: string;
    camera: {
        position: {
            lat: number;
            lng: number;
            height: number;
        };
        direction: {
            heading: number;
            pitch: number;
            roll: number;
        };
    };
    style: {
        hidePin?: boolean;
        caption?: boolean;
    };
    taskIds: number[];
    photoIds: number[];
    annotationMode: string;
    tags: ToManyList<Tag>;
    constructor(V: VasatConnection, args?: any);
}
export declare class InviteRequest extends AccountableModel<InviteRequest> implements GUIDModel {
    uid: string;
    mode: string;
    expiryDate: number;
    expiryConsumes: number;
    targetAccount: Account;
    targetProject: Project;
    createdBy: User;
    BindUser: User;
    constructor(V: VasatConnection, args?: any);
    GUID(): string;
    GUID_FIELD_NAME(): string;
}
export declare class Message extends AccountableModel<Message> implements GUIDModel {
    uid: string;
    ipAddress: string;
    status: string;
    type: string;
    thread: Message;
    invite: InviteRequest;
    jobBatch: JobBatch;
    transform: Transform;
    user: User;
    constructor(V: VasatConnection, args?: any);
    GUID(): string;
    GUID_FIELD_NAME(): string;
}
